@@ -135,9 +135,14 @@ extern	char *strcat();
 extern	char *strcpy();
 #endif 
 
+#include "../lib/sslapp.h"
 #include "ssl_port.h"
 
 #ifdef USE_SOCKS
 extern int socks_flag;
 #endif /* USE_SOCKS */
 
+#ifdef PASVHACK
+extern int pasv_hack;
+#endif
+
