@@ -17,26 +17,47 @@
 #ifdef USE_SSL
 
 #include <stdio.h>
+
+#define OLDPROTO NOPROTO
+#define NOPROTO
+#include "buffer.h"
+#undef NOPROTO
+#define NOPROTO OLDPROTO
+
 #include "x509.h"
 #include "ssl.h"
+
 extern SSL *ssl_con;
+extern SSL_CTX *ssl_ctx;
 extern int ssl_debug_flag;
 extern int ssl_only_flag;
 extern int ssl_active_flag;
 extern int ssl_verify_flag;
 extern int ssl_secure_flag;
+extern int ssl_enabled;
+
+extern int ssl_encrypt_data;
+extern SSL *ssl_data_con;
+extern int ssl_data_active_flag;
 
 extern char *my_ssl_cert_file;
 extern char *my_ssl_key_file;
 extern int ssl_certsok_flag;
 
+extern int set_ssl_trace(SSL *s);
+
+extern FILE *cin, *cout;
+
 #define is_ssl_fd(X,Y)    ( (SSL_get_fd((X))==0) || \
                             (SSL_get_fd((X))==1) || \
+                            (SSL_get_fd((X))==pdata) || \
 			    (SSL_get_fd((X))==(Y)) \
 			  )
 
 #define is_ssl_fp(X,Y)    ( ( (SSL_get_fd((X))==0) && (fileno((Y))==0) ) || \
                             ( (SSL_get_fd((X))==1) && (fileno((Y))==1) ) || \
+                            ( (SSL_get_fd((X))==pdata) && \
+			    			  (fileno((Y))==pdata) ) || \
 			    (SSL_get_fd((X))==fileno(Y)) \
 			  )
 
@@ -47,13 +68,13 @@ extern int SSL_fprintf(SSL *ssl_con, FILE *fp, char *format, ... );
 /* #define FFLUSH(X)         (ssl_active_flag && is_ssl_fp(ssl_con,(X))) ? 1 : fflush((X)) /**/
 
 #define FPRINTF           SSL_fprintf
-#define FFLUSH(X)         (ssl_active_flag && (((X)==stdout)||((X)==stderr)) ? 1 : fflush((X)) )
+#define FFLUSH(X)         (ssl_active_flag && (((X)==cin)||((X)==cout)) ? 1 : fflush((X)) )
 
-#define GETC(X)           (ssl_active_flag && (((X)==stdin)||((X)==stdin)) ? ssl_getc(ssl_con) : getc((X)) )
+#define GETC(X)           (ssl_active_flag && (((X)==cin)||((X)==cout)) ? ssl_getc(ssl_con) : getc((X)) )
 
-#define DATAGETC(X)       (ssl_data_active_flag && (fileno(X)==data) ? ssl_getc(ssl_data_con) : getc((X)) )
-#define DATAPUTC(X,Y)     (ssl_data_active_flag && (fileno(Y)==data) ? ssl_putc(ssl_data_con,(X)) : putc((X),(Y)) )
-#define DATAFLUSH(X)      (ssl_data_active_flag && (fileno(X)==data) ? ssl_putc_flush(ssl_data_con) : fflush((X)) )
+#define DATAGETC(X)       (ssl_data_active_flag && ((fileno(X)==data)||(fileno(X)==pdata)) ? ssl_getc(ssl_data_con) : getc((X)) )
+#define DATAPUTC(X,Y)     (ssl_data_active_flag && ((fileno(Y)==data)||(fileno(Y)==pdata)) ? ssl_putc(ssl_data_con,(X)) : putc((X),(Y)) )
+#define DATAFLUSH(X)      (ssl_data_active_flag && ((fileno(X)==data)||(fileno(X)==pdata)) ? ssl_putc_flush(ssl_data_con) : fflush((X)) )
 
 #else
 
@@ -61,6 +82,7 @@ extern int SSL_fprintf(SSL *ssl_con, FILE *fp, char *format, ... );
 #define DATAGETC(X)       getc((X))
 #define DATAPUTC(X,Y)     putc((X),(Y))
 #define DATAFLUSH(X)      fflush((X))
+#define FFLUSH(X)         fflush((X))
 
 #endif /* USE_SSL */
 
