@@ -43,7 +43,7 @@
 
 #else /* Something other than SunOS 4.1.x */
 
-#ifndef LINUX
+#if !defined(LINUX) && !defined(IRIX)
 
 #if defined(LIBC_SCCS) && !defined(lint)
 static char sccsid[] = "@(#)inet_addr.c	5.11 (Berkeley) 12/9/91";
@@ -167,7 +167,7 @@ inet_aton(cp, addr)
 	return (1);
 }
 
-#endif /* LINUX */
+#endif /* LINUX || IRIX */
 
 #endif /* Something other than SunOS 4.1.x */
 
